weather = {
 0: {'de': None, 'en': None, 'fr': None, 'ja': None},
 1: {'de': 'Klar',
     'en': 'Clear Skies',
     'fr': 'Dégagé',
     'ja': '快晴'},
 2: {'de': 'Heiter',
     'en': 'Fair Skies',
     'fr': 'Clair',
     'ja': '晴れ'},
 3: {'de': 'Wolkig',
     'en': 'Clouds',
     'fr': 'Couvert',
     'ja': '曇り'},
 4: {'de': 'Neblig',
     'en': 'Fog',
     'fr': 'Brouillard',
     'ja': '霧'},
 5: {'de': 'Windig', 'en': 'Wind', 'fr': 'Vent', 'ja': '風'},
 6: {'de': 'Stürmisch',
     'en': 'Gales',
     'fr': 'Vents violents',
     'ja': '暴風'},
 7: {'de': 'Regnerisch',
     'en': 'Rain',
     'fr': 'Pluie',
     'ja': '雨'},
 8: {'de': 'Wolkenbruch',
     'en': 'Showers',
     'fr': 'Pluie torrentielle',
     'ja': '暴雨'},
 9: {'de': 'Gewittrig',
     'en': 'Thunder',
     'fr': 'Orages',
     'ja': '雷'},
 10: {'de': 'Gewitter',
      'en': 'Thunderstorms',
      'fr': 'Orages violents',
      'ja': '雷雨'},
 11: {'de': 'Staubig',
      'en': 'Dust Storms',
      'fr': 'Tempêtes de poussière',
      'ja': '砂塵'},
 12: {'de': 'Sandsturm',
      'en': 'Sandstorms',
      'fr': 'Tempêtes de sable',
      'ja': '砂嵐'},
 13: {'de': 'Heiß',
      'en': 'Hot Spells',
      'fr': 'Chaud',
      'ja': '熱波'},
 14: {'de': 'Gluthitze',
      'en': 'Heat Waves',
      'fr': 'Torride',
      'ja': '灼熱波'},
 15: {'de': 'Schnee',
      'en': 'Snow',
      'fr': 'Neige',
      'ja': '雪'},
 16: {'de': 'Schneesturm',
      'en': 'Blizzards',
      'fr': 'Blizzard',
      'ja': '吹雪'},
 17: {'de': 'Unheimlich',
      'en': 'Gloom',
      'fr': 'Nébuleux',
      'ja': '妖霧'},
 18: {'de': 'Aurora',
      'en': 'Auroras',
      'fr': 'Aurore',
      'ja': 'オーロラ'},
 19: {'de': 'Dunkel',
      'en': 'Darkness',
      'fr': 'Ténèbres',
      'ja': '闇'},
 20: {'de': 'Düsternis',
      'en': 'Tension',
      'fr': 'Désespérance',
      'ja': '闘気'},
 21: {'de': 'Wolkig',
      'en': 'Clouds',
      'fr': 'Couvert',
      'ja': '曇り'},
 22: {'de': 'Wetterleuchten',
      'en': 'Storm Clouds',
      'fr': 'Orageux',
      'ja': '雷雲'},
 23: {'de': 'Tosend',
      'en': 'Rough Seas',
      'fr': 'Houle',
      'ja': '時化'},
 24: {'de': 'Tosend',
      'en': 'Rough Seas',
      'fr': 'Houle',
      'ja': '時化'},
 25: {'de': 'Finster',
      'en': 'Louring',
      'fr': 'Nuageux',
      'ja': '曇天'},
 26: {'de': 'Gluthitze',
      'en': 'Heat Waves',
      'fr': 'Torride',
      'ja': '灼熱波'},
 27: {'de': 'Unheimlich',
      'en': 'Gloom',
      'fr': 'Nébuleux',
      'ja': '妖霧'},
 28: {'de': 'Stürmisch',
      'en': 'Gales',
      'fr': 'Vents violents',
      'ja': '暴風'},
 29: {'de': 'Rauchschwaden',
      'en': 'Eruptions',
      'fr': 'Éruptions',
      'ja': '噴煙'},
 30: {'de': 'Heiter',
      'en': 'Fair Skies',
      'fr': 'Clair',
      'ja': '晴れ'},
 31: {'de': 'Heiter',
      'en': 'Fair Skies',
      'fr': 'Clair',
      'ja': '晴れ'},
 32: {'de': 'Heiter',
      'en': 'Fair Skies',
      'fr': 'Clair',
      'ja': '晴れ'},
 33: {'de': 'Heiter',
      'en': 'Fair Skies',
      'fr': 'Clair',
      'ja': '晴れ'},
 34: {'de': 'Heiter',
      'en': 'Fair Skies',
      'fr': 'Clair',
      'ja': '晴れ'},
 35: {'de': 'Blendend',
      'en': 'Irradiance',
      'fr': 'Rayonnement',
      'ja': '極光'},
 36: {'de': 'Kernstrahlung',
      'en': 'Core Radiation',
      'fr': 'Radiations du Cœur',
      'ja': '龍核'},
 37: {'de': 'Kernstrahlung',
      'en': 'Core Radiation',
      'fr': 'Radiations du Cœur',
      'ja': '龍核'},
 38: {'de': 'Kernstrahlung',
      'en': 'Core Radiation',
      'fr': 'Radiations du Cœur',
      'ja': '龍核'},
 39: {'de': 'Kernstrahlung',
      'en': 'Core Radiation',
      'fr': 'Radiations du Cœur',
      'ja': '龍核'},
 40: {'de': 'Wolkenschleier',
      'en': 'Shelf Clouds',
      'fr': 'Amas nuageux',
      'ja': '群雲'},
 41: {'de': 'Wolkenschleier',
      'en': 'Shelf Clouds',
      'fr': 'Amas nuageux',
      'ja': '群雲'},
 42: {'de': 'Wolkenschleier',
      'en': 'Shelf Clouds',
      'fr': 'Amas nuageux',
      'ja': '群雲'},
 43: {'de': 'Wolkenschleier',
      'en': 'Shelf Clouds',
      'fr': 'Amas nuageux',
      'ja': '群雲'},
 44: {'de': 'Bedrückend',
      'en': 'Oppression',
      'fr': 'Oppression',
      'ja': '神意'},
 45: {'de': 'Bedrückend',
      'en': 'Oppression',
      'fr': 'Oppression',
      'ja': '神意'},
 46: {'de': 'Bedrückend',
      'en': 'Oppression',
      'fr': 'Oppression',
      'ja': '神意'},
 47: {'de': 'Bedrückend',
      'en': 'Oppression',
      'fr': 'Oppression',
      'ja': '神意'},
 48: {'de': 'Bedrückend',
      'en': 'Oppression',
      'fr': 'Oppression',
      'ja': '神意'},
 49: {'de': 'Schattenwind',
      'en': 'Umbral Wind',
      'fr': 'Vent ombral',
      'ja': '霊風'},
 50: {'de': 'Schattengewitter',
      'en': 'Umbral Static',
      'fr': 'Charges ombrales',
      'ja': '放電'},
 51: {'de': 'Qualm',
      'en': 'Smoke',
      'fr': 'Fumées',
      'ja': '煙霧'},
 52: {'de': 'Heiter',
      'en': 'Fair Skies',
      'fr': 'Clair',
      'ja': '晴れ'},
 53: {'de': 'Königsgewitter',
      'en': 'Royal Levin',
      'fr': 'Éclairs royaux',
      'ja': '獣雷'},
 54: {'de': 'Hochspannung',
      'en': 'Hyperelectricity',
      'fr': 'Hyperélectricité',
      'ja': '雷波'},
 55: {'de': 'Königsgewitter',
      'en': 'Royal Levin',
      'fr': 'Éclairs royaux',
      'ja': '獣雷'},
 56: {'de': 'Numinos',
      'en': 'Oppression',
      'fr': 'Oppression',
      'ja': '神意'},
 57: {'de': 'Gewittrig',
      'en': 'Thunder',
      'fr': 'Orages',
      'ja': '雷'},
 58: {'de': 'Gewittrig',
      'en': 'Thunder',
      'fr': 'Orages',
      'ja': '雷'},
 59: {'de': None, 'en': 'CutScene', 'fr': None, 'ja': None},
 60: {'de': 'Mystisch',
      'en': 'Multiplicity',
      'fr': 'Multiplicité',
      'ja': '神秘'},
 61: {'de': 'Mystisch',
      'en': 'Multiplicity',
      'fr': 'Multiplicité',
      'ja': '神秘'},
 62: {'de': 'Regnerisch',
      'en': 'Rain',
      'fr': 'Pluie',
      'ja': '雨'},
 63: {'de': 'Heiter',
      'en': 'Fair Skies',
      'fr': 'Clair',
      'ja': '晴れ'},
 64: {'de': 'Regnerisch',
      'en': 'Rain',
      'fr': 'Pluie',
      'ja': '雨'},
 65: {'de': 'Heiter',
      'en': 'Fair Skies',
      'fr': 'Clair',
      'ja': '晴れ'},
 66: {'de': 'Hass',
      'en': 'Dragonstorms',
      'fr': 'Tempête de haine',
      'ja': '邪天'},
 67: {'de': 'Hass',
      'en': 'Dragonstorms',
      'fr': 'Tempête de haine',
      'ja': '邪天'},
 68: {'de': 'Unterirdisch',
      'en': 'Subterrain',
      'fr': 'Souterrain',
      'ja': '晴れ'},
 69: {'de': 'Gerechtigkeit',
      'en': 'Concordance',
      'fr': 'Harmonie',
      'ja': '調和'},
 70: {'de': 'Gerechtigkeit',
      'en': 'Concordance',
      'fr': 'Harmonie',
      'ja': '調和'},
 71: {'de': 'Zeitfluss',
      'en': 'Beyond Time',
      'fr': 'Hors du temps',
      'ja': '時流'},
 72: {'de': 'Zeitfluss',
      'en': 'Beyond Time',
      'fr': 'Hors du temps',
      'ja': '時流'},
 73: {'de': 'Zeitfluss',
      'en': 'Beyond Time',
      'fr': 'Hors du temps',
      'ja': '時流'},
 74: {'de': 'Dämonisch unendlich',
      'en': 'Demonic Infinity',
      'fr': 'Infini démoniaque',
      'ja': '鬼気'},
 75: {'de': 'Dämonisch unendlich',
      'en': 'Demonic Infinity',
      'fr': 'Infini démoniaque',
      'ja': '鬼気'},
 76: {'de': 'Dämonisch unendlich',
      'en': 'Demonic Infinity',
      'fr': 'Infini démoniaque',
      'ja': '鬼気'},
 77: {'de': 'Dimensionsspaltend',
      'en': 'Dimensional Disruption',
      'fr': 'Perturbation dimensionnelle',
      'ja': '次元'},
 78: {'de': 'Dimensionsspaltend',
      'en': 'Dimensional Disruption',
      'fr': 'Perturbation dimensionnelle',
      'ja': '次元'},
 79: {'de': 'Dimensionsspaltend',
      'en': 'Dimensional Disruption',
      'fr': 'Perturbation dimensionnelle',
      'ja': '次元'},
 80: {'de': 'Feiersturm',
      'en': 'Revelstorms',
      'fr': 'Tempête festive',
      'ja': '嵐天'},
 81: {'de': 'Feiersturm',
      'en': 'Revelstorms',
      'fr': 'Tempête festive',
      'ja': '嵐天'},
 82: {'de': 'Ewigschön',
      'en': 'Eternal Bliss',
      'fr': 'Béatitude éternelle',
      'ja': '美天'},
 83: {'de': 'Ewigschön',
      'en': 'Eternal Bliss',
      'fr': 'Béatitude éternelle',
      'ja': '美天'},
 84: {'de': 'Drachensturm',
      'en': 'Wyrmstorms',
      'fr': 'Tempête draconique',
      'ja': '龍天'},
 85: {'de': 'Drachensturm',
      'en': 'Wyrmstorms',
      'fr': 'Tempête draconique',
      'ja': '龍天'},
 86: {'de': 'Feiersturm',
      'en': 'Revelstorms',
      'fr': 'Tempête festive',
      'ja': '嵐天'},
 87: {'de': 'Blitzsturm',
      'en': 'Quicklevin',
      'fr': 'Vif-orage',
      'ja': '迅雷'},
 88: {'de': 'Gewittrig',
      'en': 'Thunder',
      'fr': 'Orages',
      'ja': '雷'},
 89: {'de': 'Dimensionsspaltend',
      'en': 'Dimensional Disruption',
      'fr': 'Perturbation dimensionnelle',
      'ja': '次元'},
 90: {'de': 'Heiter',
      'en': 'Fair Skies',
      'fr': 'Clair',
      'ja': '晴れ'},
 91: {'de': 'Klar',
      'en': 'Clear Skies',
      'fr': 'Dégagé',
      'ja': '快晴'},
 92: {'de': 'Weißer Zyklon',
      'en': 'White Cyclones',
      'fr': 'Tempête blanche',
      'ja': '白嵐'},
 93: {'de': 'Weißer Zyklon',
      'en': 'White Cyclones',
      'fr': 'Tempête blanche',
      'ja': '白嵐'},
 94: {'de': 'Weißer Zyklon',
      'en': 'White Cyclones',
      'fr': 'Tempête blanche',
      'ja': '白嵐'},
 95: {'de': 'Ultimativ',
      'en': 'Ultimania',
      'fr': 'Fantasmagorique',
      'ja': '幻想'},
 96: {'de': 'Weißer Zyklon',
      'en': 'White Cyclones',
      'fr': 'Tempête blanche',
      'ja': '白嵐'},
 97: {'de': 'Dunkle Mondnacht',
      'en': 'Moonlight',
      'fr': 'Clair de lune',
      'ja': '月夜'},
 98: {'de': 'Dunkle Mondnacht',
      'en': 'Moonlight',
      'fr': 'Clair de lune',
      'ja': '月夜'},
 99: {'de': 'Dunkle Mondnacht',
      'en': 'Moonlight',
      'fr': 'Clair de lune',
      'ja': '月夜'},
 100: {'de': 'Dunkle Mondnacht',
       'en': 'Moonlight',
       'fr': 'Clair de lune',
       'ja': '月夜'},
 101: {'de': 'Heiter',
       'en': 'Fair Skies',
       'fr': 'Clair',
       'ja': '晴れ'},
 102: {'de': 'Rotlodernd',
       'en': 'Scarlet',
       'fr': 'Vermillon',
       'ja': '朱炎 '},
 103: {'de': 'Rotlodernd',
       'en': 'Scarlet',
       'fr': 'Vermillon',
       'ja': '朱炎 '},
 104: {'de': 'Rotlodernd',
       'en': 'Scarlet',
       'fr': 'Vermillon',
       'ja': '朱炎 '},
 105: {'de': 'Heiter',
       'en': 'Fair Skies',
       'fr': 'Clair',
       'ja': '晴れ'},
 106: {'de': 'Heiter',
       'en': 'Fair Skies',
       'fr': 'Clair',
       'ja': '晴れ'},
 107: {'de': 'Heiter',
       'en': 'Fair Skies',
       'fr': 'Clair',
       'ja': '晴れ'},
 108: {'de': 'Heiter',
       'en': 'Fair Skies',
       'fr': 'Clair',
       'ja': '晴れ'},
 109: {'de': 'Feuer',
       'en': 'Flames',
       'fr': 'Flammes',
       'ja': '火炎'},
 110: {'de': 'Tsunami',
       'en': 'Tsunamis',
       'fr': 'Raz-de-marée',
       'ja': '津波'},
 111: {'de': 'Tornado',
       'en': 'Cyclones',
       'fr': 'Tornade',
       'ja': '竜巻'},
 112: {'de': 'Erdbeben',
       'en': 'Geostorms',
       'fr': 'Séisme',
       'ja': '地震 '},
 113: {'de': 'Blauschimmernd',
       'en': 'True Blue',
       'fr': 'Azur',
       'ja': '青春'},
 114: {'de': 'Blauschimmernd',
       'en': 'True Blue',
       'fr': 'Azur',
       'ja': '青春'},
 115: {'de': 'Blauschimmernd',
       'en': 'True Blue',
       'fr': 'Azur',
       'ja': '青春'},
 116: {'de': 'Astrale Turbulenzen',
       'en': 'Umbral Turbulence',
       'fr': 'Turbulences ombrales',
       'ja': '乱霊流'},
 117: {'de': 'Blauschimmernd',
       'en': 'True Blue',
       'fr': 'Azur',
       'ja': '青春'},
 118: {'de': None, 'en': None, 'fr': None, 'ja': None},
 119: {'de': None, 'en': None, 'fr': None, 'ja': None},
 120: {'de': None, 'en': None, 'fr': None, 'ja': None},
 121: {'de': None, 'en': None, 'fr': None, 'ja': None}
}



import pytest

from EorzeaEnv import EorzeaTime
from EorzeaEnv import EorzeaWeather


class TestForecast:
    def test_forecast(self):
        assert EorzeaWeather.forecast(
            'Eureka Pagos', 1542651599.999
        ) == 'Fog'
        assert EorzeaWeather.forecast(
            'Eureka Pyros', 1542591400.045
        ) == 'Umbral Wind'
        assert EorzeaWeather.forecast(
            'Sigmascape V4.0', 1542591400.045
        ) == 'Dimensional Disruption'
        assert EorzeaWeather.forecast(
            'Bowl of Embers', 1542591400.045
        ) == 'Heat Waves'
        assert EorzeaWeather.forecast(
            'the ruby sea', 1542591400.045
        ) == 'Fair Skies'
        assert EorzeaWeather.forecast(
            'sea of clouds', 1542591400.045
        ) == 'Fog'
        assert EorzeaWeather.forecast(
            'asdfUpper aetheroacoustic exploratory sitea dsf',
            1542591400.045,
            strict=False
        ) == 'Fair Skies'
        assert EorzeaWeather.forecast(
            'Eureka Hydatos', 1542591400.045
        ) == 'Thunderstorms'

    def test_field(self):
        for t in (EorzeaTime.weather_period(10)):
            weather = EorzeaWeather.forecast('Eureka Pyros', t)
            assert isinstance(weather, str)

        with pytest.raises(KeyError):
            pyros_weather = EorzeaWeather.forecast(
                'EuPyros', 1542591400.045
            )

    def test_localize(self):
        assert EorzeaWeather.forecast(
            'Eureka Pagos',
            1542651599.999,
            lang='en'
        ) == 'Fog'
        assert EorzeaWeather.forecast(
            'Eureka Pagos',
            1542651599.999,
            lang='ja'
        ) == '霧'
        assert EorzeaWeather.forecast(
            'Eureka Pagos',
            1542651599.999,
            lang='de'
        ) == 'Neblig'
        assert EorzeaWeather.forecast(
            'Eureka Pagos',
            1542651599.999,
            lang='fr'
        ) == 'Brouillard'



import pytest

from EorzeaEnv import EorzeaTime


class TestTime:
    def test_step(self):
        timelist = [t for t in EorzeaTime.weather_period(10)]
        assert len(timelist) is 10

    def test_time(self):
        assert isinstance(EorzeaTime.now().minute, int)
        assert isinstance(EorzeaTime.now().hour, int)
        test_time = (
            (13, 1, 10, 50),
            (12, 35, 10, 50),
            (12, 1, 25, 50),
            (12, 1, 10, 61)
        )
        with pytest.raises(ValueError):
            for t in test_time:
                M, S, h, m = t
                EorzeaTime(M, S, h, m)
        with pytest.raises(TypeError):
            EorzeaTime("kappa", 1, 10, 50)



import math
from time import time as _time
from typing import Generator, Tuple

_YEAR = 33177600
_MOON = 2764800
_DAY = 86400
_HOUR = 3600
_MINUTE = 60
_SECOND = 1
_EORZEA_MINUTE = 60
_EORZEA_BELL = 60
_EORZEA_SUN = 24
_EORZEA_MOON = 32
_EORZEA_YEAR = 12
_EORZEA_TIME_CONST = 3600.0 / 175.0
_MILLISECOND_EORZEA_PER_MINUTE = (2 + 11/12) * 1000


class EorzeaTime:
    """
    EorzeaTime(moon, sun, hour, minute)
    """

    __slots__ = '_moon', '_sun', '_hour', '_minute', '_phase', '_guardian'

    def __new__(cls, moon: int, sun: int, hour: int, minute: int):
        instance = super().__new__(cls)
        instance._hour, instance._minute = _check_time_field(hour, minute)
        moon, instance._sun = _check_date_field(moon, sun)
        instance._moon = _calculate_moon(moon)
        instance._phase = _check_phase_field(_calculate_phase(sun))
        instance._guardian = _the_twelve(moon)
        return instance

    @property
    def moon(self):
        return self._moon

    @property
    def sun(self):
        return self._sun

    @property
    def hour(self):
        return self._hour

    @property
    def minute(self):
        return self._minute

    @property
    def phase(self):
        return self._phase

    @property
    def guardian(self):
        return self._guardian

    @classmethod
    def now(cls):
        """
        get current EorzeaTime

        Returns
        -------
        [EorzeaTime object]
            current EorzeaTime
        """

        t = _time()
        return cls._fromtimestamp(t)

    @classmethod
    def _fromtimestamp(cls, t: float):
        et = t * _EORZEA_TIME_CONST
        moon = math.ceil(et / _MOON % _EORZEA_YEAR)
        sun = math.ceil(et / _DAY % _EORZEA_MOON)
        hh = int(et / _HOUR % _EORZEA_SUN)
        mm = int(et / _MINUTE % _EORZEA_BELL)
        return cls(moon, sun, hh, mm)

    @classmethod
    def weather_period(cls, step=5) -> Generator[float, int, None]:
        """
        generate weather period

        Parameters
        ----------
        step : int, optional
            quantity of period you want, by default 5

        Returns
        -------
        Generator[float, int, None]
            a generator of weather period
        """

        period = _weather_period_generator(cls._weather_period_start(), step)
        return period

    @classmethod
    def _weather_period_start(cls) -> float:
        t = _time()
        et = t * _EORZEA_TIME_CONST
        lt = int(et / 28800) * 28800 / _EORZEA_TIME_CONST
        return lt

    def _cls_to_str(self) -> str:
        return "{}({}, {}, {:02d}, {:02d}, {:.2f}, {})".format(
            self.__class__.__qualname__,
            self.moon, self.sun,
            self.hour, self.minute, self.phase,
            self.guardian)

    def __repr__(self):
        return self._cls_to_str()

    def __str__(self):
        return self._cls_to_str()


def check_int(func):
    def wrap(*values):
        for value in values:
            if not isinstance(value, int):
                raise TypeError("integer argument required")
        return func(*values)
    return wrap


def _weather_period_generator(min, step: int) -> Generator[float, int, None]:
    if not isinstance(step, int):
        raise TypeError("integer argument required")
    n, i = 0, min
    while n < step:
        yield i
        i += 1400
        n += 1


def _the_twelve(moon: int) -> str:
    the_twelve = [
        "Halone",
        "Menphina",
        "Thaliak",
        "Nymeia",
        "Llymlaen",
        "Oschon",
        "Byregot",
        "Rhalgr",
        "Azeyma",
        "Nald'thal",
        "Nophica",
        "Althyk"
    ]
    return the_twelve[moon - 1]


def _calculate_moon(moon: int) -> str:
    th = ["First", "Second", "Third", "Fourth", "Fifth", "Sixth"]
    M_th = th[math.ceil(moon / 2) - 1]
    M_type = _astral_or_embral(moon)
    return "{} {} Moon".format(M_th, M_type)


def _astral_or_embral(moon: int) -> str:
    return "Astral" if moon % 2 else "Embral"


def _calculate_phase(sun: int) -> int:
    if sun <= 20:
        return 1 - int(abs(20 - sun) / 4) / 4
    if sun > 20:
        return int(abs(36 - sun) / 4) / 4


def _calculate_pphase(sun: int) -> int:
    if sun <= 20:
        return round((sun - 1) / 19, 2)
    if sun >= 20:
        return round(1 - (sun - 20) / 13, 2)


@check_int
def _check_time_field(hour: int, minute: int) -> Tuple[int, int]:
    if not 0 <= hour <= 23:
        raise ValueError('hour must be in 0..23', hour)
    if not 0 <= minute <= 59:
        raise ValueError('minute must be in 0..59', minute)
    return hour, minute


@check_int
def _check_date_field(moon: int, sun: int) -> Tuple[int, int]:
    if not 1 <= moon <= 12:
        raise ValueError('moon must be in 1..12', moon)
    if not 1 <= sun <= 32:
        raise ValueError('sun must be in 1..32', sun)
    return moon, sun


def _check_phase_field(phase: float) -> float:
    if not 0 <= phase <= 1:
        raise ValueError('phase must be in 0..1', phase)
    return phase


if __name__ == "__main__":
    while True:
        t = str(EorzeaTime.now())
        print("\r"+t, end="")



territory = {
 'aery': 28,
 'aetherochemical research facility': 0,
 'akh afah amphitheatre': 46,
 'ala mhigo': 0,
 'alexander': 0,
 'amdapor keep': 28,
 'antitower': 0,
 'aquapolis': 0,
 'arm of the father': 0,
 'arm of the son': 0,
 'astragalos': 0,
 'aurum vale': 0,
 'azim steppe': 85,
 'azys lla': 54,
 "baelsar's wall": 40,
 "bardam's mettle": 0,
 'battlehall': 0,
 'binding coil of bahamut': 0,
 'blessed treasury': 77,
 'blue sky': 0,
 'bokairo inn': 82,
 'bowl of embers': 25,
 "brayflox's longstop": 0,
 'breath of the creator': 0,
 'burden of the father': 0,
 'burden of the son': 0,
 'burn': 0,
 'burning heart': 44,
 'carteneau flats: borderland ruins': 0,
 'castrum abania': 0,
 'castrum fluminis': 0,
 'castrum meridianum': 0,
 'central azys lla': 0,
 'central decks': 0,
 'central shroud': 3,
 'central thanalan': 10,
 'chocobo square': 0,
 'chrysalis': 0,
 'churning mists': 52,
 'cloud nine': 0,
 'coerthas central highlands': 21,
 'coerthas western highlands': 49,
 'command room': 14,
 'company workshop - mist': 0,
 'company workshop - shirogane': 0,
 'company workshop - the goblet': 0,
 'company workshop - the lavender beds': 0,
 'containment bay p1t6': 69,
 'containment bay s1t7': 66,
 'containment bay z1t9': 75,
 'copperbell mines': 0,
 'crystal tower training grounds': 90,
 'cuff of the father': 0,
 'cuff of the son': 0,
 "cutter's cry": 0,
 "dalamud's shadow": 0,
 'deltascape v1.0': 88,
 'deltascape v2.0': 88,
 'deltascape v3.0': 88,
 'deltascape v4.0': 88,
 'diadem': 60,
 'doma castle': 0,
 'doman enclave': 84,
 'dravanian forelands': 50,
 'dravanian hinterlands': 51,
 'drowned city of skalla': 0,
 'dun scaith': 58,
 'dusk vigil': 42,
 'dzemael darkhold': 0,
 'east shroud': 4,
 'eastern la noscea': 18,
 'eastern thanalan': 11,
 'eighteenth floor': 0,
 'emanation': 87,
 'eorzean alliance headquarters': 0,
 'eorzean subterrane': 0,
 'eureka anemos': 91,
 'eureka hydatos': 100,
 'eureka pagos': 94,
 'eureka pyros': 96,
 'eyes of the creator': 0,
 "fall of belah'dia": 0,
 'feasting grounds': 65,
 'fields of glory': 67,
 'first altar of djanan qhat': 0,
 'fist of the father': 0,
 'fist of the son': 0,
 'flame barracks': 0,
 'fold': 0,
 'fortemps manor': 0,
 'foundation': 47,
 'fractal continuum': 0,
 'fringes': 79,
 "frondale's ward for friendless foundlings": 0,
 'ghimlyt dark': 0,
 'goblet': 33,
 'gold saucer': 0,
 'great gubal library': 0,
 'great hunt': 0,
 'griffin crossing': 0,
 'halatali': 0,
 'hall of summoning': 0,
 'hall of the bestiarii': 0,
 'haukke manor': 0,
 'haunted manor': 0,
 'heart of the creator': 0,
 'heart of the sworn': 0,
 'heaven-on-high': 0,
 "hells' kier": 98,
 "hells' lid": 0,
 'hidden gorge': 0,
 'holocharts': 0,
 'hourglass': 0,
 'house of the fierce': 84,
 'howling eye': 26,
 'hullbreaker isle': 0,
 'ic-04 main bridge': 0,
 'ic-06 central decks': 0,
 'ic-06 main bridge': 0,
 'ic-06 regeneration grid': 0,
 'idyllshire': 55,
 'intercessory': 0,
 'interdimensional rift': 92,
 'jade stoa': 93,
 'keeper of the lake': 74,
 'kienkan': 0,
 'kobai goten apartment': 0,
 'kobai goten apartment lobby': 0,
 'kugane': 82,
 'kugane castle': 0,
 'kugane ohashi': 0,
 'labyrinth of the ancients': 0,
 'lavender beds': 34,
 "leofard's chambers": 0,
 'lichenweed': 73,
 'lightfeather proving grounds': 0,
 'lily hills apartment': 0,
 'lily hills apartment lobby': 0,
 'limitless blue': 28,
 'limsa lominsa': 0,
 'limsa lominsa lower decks': 15,
 'limsa lominsa upper decks': 14,
 'lochs': 81,
 'lost canals of uznair': 0,
 'lost city of amdapor': 40,
 'lotus stand': 0,
 'lower aetheroacoustic exploratory site': 0,
 'lower la noscea': 17,
 'maelstrom barracks': 0,
 'main bridge': 0,
 'manderville tables': 0,
 "matoya's cave": 0,
 'middle la noscea': 16,
 'misery': 36,
 'mist': 14,
 'mizzenmast inn': 0,
 'mor dhona': 22,
 'mordion gaol': 0,
 'navel': 23,
 'neverreap': 0,
 'new gridania': 1,
 'north shroud': 6,
 'northern thanalan': 13,
 'old gridania': 2,
 'omega control': 0,
 'orbonne monastery': 0,
 'outer coil': 28,
 'outer la noscea': 24,
 'palace of the dead': 0,
 'parrock': 0,
 'peaks': 80,
 'pharos sirius': 28,
 'pillars': 48,
 'porta decumana': 31,
 'praetorium': 0,
 'prima vista bridge': 0,
 'prima vista tiring room': 0,
 'private chambers - mist': 0,
 'private chambers - shirogane': 0,
 'private chambers - the goblet': 0,
 'private chambers - the lavender beds': 0,
 'private cottage - mist': 0,
 'private cottage - shirogane': 0,
 'private cottage - the goblet': 0,
 'private cottage - the lavender beds': 0,
 'private house - mist': 0,
 'private house - shirogane': 0,
 'private house - the goblet': 0,
 'private house - the lavender beds': 0,
 'private mansion - mist': 0,
 'private mansion - shirogane': 0,
 'private mansion - the goblet': 0,
 'private mansion - the lavender beds': 0,
 'psiscape v1.0': 92,
 'psiscape v2.0': 92,
 'ragnarok': 0,
 'ragnarok central core': 0,
 'ragnarok drive cylinder': 0,
 'ragnarok main bridge': 0,
 'reisen temple': 0,
 'reisen temple road': 0,
 'resonatorium': 0,
 "rhalgr's reach": 78,
 'rhotano sea': 0,
 'ridorana cataract': 0,
 'ridorana lighthouse': 0,
 'rising stones': 0,
 'roost': 0,
 'royal airship landing': 76,
 'royal city of rabanastre': 0,
 'royal menagerie': 0,
 'royal palace': 0,
 'ruby bazaar offices': 0,
 'ruby sea': 83,
 'ruling chamber': 0,
 'sacrificial chamber': 0,
 "saint endalim's scholasticate": 0,
 "saint mocianne's arboretum": 0,
 'sanctum of the twelve': 0,
 'sastasha': 0,
 'sea of clouds': 53,
 'seal rock': 59,
 'seat of the first bow': 0,
 'seat of the lord commander': 0,
 'shifting altars of uznair': 0,
 'shirogane': 82,
 'shisui of the violet tides': 0,
 'sigmascape v1.0': 92,
 'sigmascape v2.0': 92,
 'sigmascape v3.0': 92,
 'sigmascape v4.0': 92,
 'singularity reactor': 56,
 'sirensong sea': 36,
 'snowcloak': 42,
 'sohm al': 0,
 'sohr khai': 0,
 'soul of the creator': 0,
 'south shroud': 5,
 'southern thanalan': 12,
 'steps of faith': 28,
 'stone vigil': 27,
 'striking tree': 43,
 "sultana's breath apartment": 0,
 "sultana's breath apartment lobby": 0,
 'sunken temple of qarn': 0,
 "swallow's compass": 0,
 'syrcus tower': 0,
 'tam-tara deepcroft': 0,
 'temple of the fist': 0,
 'thok ast thok': 57,
 'thornmarch': 30,
 'thousand maws of toto-rak': 0,
 'topmast apartment': 0,
 'topmast apartment lobby': 0,
 'transparency': 76,
 'twin adder barracks': 0,
 "ul'dah - steps of nald": 7,
 "ul'dah - steps of thal": 8,
 'ultimacy': 26,
 'upper aetheroacoustic exploratory site': 0,
 'upper la noscea': 20,
 'vault': 0,
 'void ark': 37,
 'waking sands': 0,
 "wanderer's palace": 0,
 'weeping city of mhach': 0,
 'weeping saint': 21,
 'western la noscea': 19,
 'western thanalan': 9,
 'whorleater': 38,
 "wolves' den pier": 29,
 'world of darkness': 0,
 'wreath of snakes': 99,
 'xelphatol': 40,
 'yanxia': 84
}



import setuptools

with open("README.md", "r", encoding="UTF-8") as f:
    long_description = f.read()

setuptools.setup(
    name="EorzeaEnv",
    version="1.3.0",
    author="Elton H.Y. Chou",
    author_email="plscd748@gmail.com",
    license="MIT",
    description="Final Fantasy XIV weather & time tools.",
    keywords='eorzea ffxiv ff14',
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/EltonChou/EorzeaEnv",
    packages=setuptools.find_packages(),
    install_requires=['numpy', 'pytest'],
    python_requires='>=3.6.0',
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "Topic :: Utilities",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    project_urls={
        'Bug Reports': 'https://github.com/EltonChou/EorzeaEnv/issues',
        'Source': 'https://github.com/EltonChou/EorzeaEnv',
        'Thanks!': 'https://github.com/Rogueadyn/SaintCoinach',
    },
)
